@@ -23,7 +23,7 @@ pub use events::*;
 pub use proposal::*;
 pub use state::*;
 
-declare_id!("RLMVZzDAFw8aWZiwBzBmcddtcs2d3shtiuYEKJ3ptwj");
+declare_id!("Govz1VyoyLD5BL6CSCxUJLVLsQHRwjfFj1prNsdNg5Jw");
 
 /// The [govern] program.
 #[program]
@@ -123,6 +123,7 @@ pub mod govern {
         emit!(ProposalActivateEvent {
             governor: proposal.governor.key(),
             proposal: proposal.key(),
+            voting_ends_at: proposal.voting_ends_at,
         });
 
         Ok(())
@@ -204,8 +205,15 @@ pub mod govern {
         ctx: Context<SetGovernanceParams>,
         params: GovernanceParameters,
     ) -> ProgramResult {
+        let prev_params = ctx.accounts.governor.params;
         ctx.accounts.governor.params = params;
 
+        emit!(GovernorSetParamsEvent {
+            governor: ctx.accounts.governor.key(),
+            prev_params,
+            params,
+        });
+
         Ok(())
     }
 
